@@ -1,4 +1,5 @@
 """AwesomeVersion."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Dict
@@ -27,44 +28,9 @@ if TYPE_CHECKING:
     from .typing import EnsureStrategyIterableType, EnsureStrategyType, VersionType
 
 
-class _AwesomeVersionBase(str):
-    """Base class for AwesomeVersion to allow the usage of the default JSON encoder."""
-
-    def __init__(self, string: str):
-        str.__init__(string)
-
-    def __new__(
-        cls,
-        version: str,
-        *_: Any,
-        **__: Any,
-    ) -> "_AwesomeVersionBase":
-        """Create a new AwesomeVersion object."""
-
-        return super().__new__(cls, version)
-
-
-class AwesomeVersion(_AwesomeVersionBase):
+class AwesomeVersion(str):
     """
     AwesomeVersion class.
-
-    **args**:
-
-    version:
-        The version to create a AwesomeVersion object from
-
-    **kwargs**:
-
-    ensure_strategy:
-        Match the AwesomeVersion object against spesific
-        strategies when creating if. If it does not match
-        AwesomeVersionStrategyException will be raised
-
-    find_first_match:
-        If True, the version given will be scanned for the first
-        match of the given ensure_strategy. Raises
-        AwesomeVersionStrategyException If it is not found
-        for any of the given strategies.
     """
 
     _version: str = ""
@@ -77,29 +43,32 @@ class AwesomeVersion(_AwesomeVersionBase):
     def __init__(
         self,  # pylint: disable=unused-argument
         version: VersionType,
-        *args: Any,
+        *,
         ensure_strategy: EnsureStrategyType = None,
         find_first_match: bool = False,
         **kwargs: Any,
     ) -> None:
-        """Initialize AwesomeVersion."""
-        if args:
-            warn(
-                "Positional argument for ensure_strategy is deprecated. "
-                "This will be removed in 2023, use keyword argument instead",
-                category=DeprecationWarning,
-                stacklevel=2,
-            )
-            ensure_strategy = args[0]
-            if len(args) == 2:
-                warn(
-                    "Positional argument for find_first_match is deprecated. "
-                    "This will be removed in 2023, use keyword argument instead",
-                    category=DeprecationWarning,
-                    stacklevel=2,
-                )
-                find_first_match = args[1]
+        """
+        Initialize AwesomeVersion.
 
+        **args**:
+
+        version:
+            The version to create a AwesomeVersion object from
+
+        **kwargs**:
+
+        ensure_strategy:
+            Match the AwesomeVersion object against spesific
+            strategies when creating if. If it does not match
+            AwesomeVersionStrategyException will be raised
+
+        find_first_match:
+            If True, the version given will be scanned for the first
+            match of the given ensure_strategy. Raises
+            AwesomeVersionStrategyException If it is not found
+            for any of the given strategies.
+        """
         self._version = (
             version._version if isinstance(version, AwesomeVersion) else str(version)
         )
@@ -109,7 +78,8 @@ class AwesomeVersion(_AwesomeVersionBase):
 
         if find_first_match and not ensure_strategy:
             warn(
-                "Can not use find_first_match without ensure_strategy",
+                "Can not use find_first_match without ensure_strategy, "
+                "this is ignored and will start raising an exception in 2025.",
                 stacklevel=2,
             )
 
@@ -141,12 +111,22 @@ class AwesomeVersion(_AwesomeVersionBase):
         if self._version and self._version[-1] == ".":
             self._version = self._version[:-1]
 
-        super().__init__(self._version)
+        str.__init__(self._version)
+
+    def __new__(
+        cls,
+        version: str,
+        *_: Any,
+        **__: Any,
+    ) -> AwesomeVersion:
+        """Create a new AwesomeVersion object."""
+
+        return super().__new__(cls, version)
 
     def __enter__(self) -> AwesomeVersion:
         return self
 
-    def __exit__(self, *_: Any, **__: Any) -> bool:
+    def __exit__(self, *_: Any, **__: Any) -> None:
         pass
 
     def __repr__(self) -> str:
@@ -207,6 +187,9 @@ class AwesomeVersion(_AwesomeVersionBase):
     def __sub__(self, compareto: object) -> AwesomeVersionDiff:
         return self.diff(compareto)
 
+    def __hash__(self) -> int:
+        return str.__hash__(self.string)
+
     def diff(self, compareto: VersionType) -> AwesomeVersionDiff:
         """Return a dictionary with differences between 2 AwesomeVersion objects."""
         if isinstance(compareto, (str, float, int)):
@@ -215,16 +198,30 @@ class AwesomeVersion(_AwesomeVersionBase):
             raise AwesomeVersionCompareException("Not a valid AwesomeVersion object")
         return AwesomeVersionDiff(
             {
-                "major": self.major != compareto.major,
-                "minor": self.minor != compareto.minor,
-                "patch": self.patch != compareto.patch,
+                "major": str(self.major) != str(compareto.major),
+                "minor": str(self.minor) != str(compareto.minor),
+                "patch": str(self.patch) != str(compareto.patch),
                 "modifier": self.modifier != compareto.modifier,
                 "strategy": self.strategy != compareto.strategy,
             }
         )
 
+    def in_range(self, lowest: VersionType, highest: VersionType) -> bool:
+        """Check if version is in range."""
+        if isinstance(lowest, (str, float, int)):
+            lowest = AwesomeVersion(lowest)
+        if isinstance(highest, (str, float, int)):
+            highest = AwesomeVersion(highest)
+        if not isinstance(lowest, AwesomeVersion):
+            raise AwesomeVersionCompareException("Lowest version is not valid")
+        if not isinstance(highest, AwesomeVersion):
+            raise AwesomeVersionCompareException("Highest version is not valid")
+        return lowest <= self <= highest
+
     def section(self, idx: int) -> int:
         """Return the value of the specified section of the version."""
+        if self.strategy == AwesomeVersionStrategy.HEXVER:
+            return int(self.string, 16) if idx == 0 else 0
         if self.sections >= (idx + 1):
             match = RE_DIGIT.match(self.string.split(".")[idx] or "")
             if match and match.groups():
@@ -302,7 +299,7 @@ class AwesomeVersion(_AwesomeVersionBase):
                 [
                     section.split(self.modifier_type)[-1]
                     for section in self.string.split(".")
-                    if modifier is None or section != modifier
+                    if section and (modifier is None or section != modifier)
                 ]
             )
         return self._sections
@@ -312,13 +309,14 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the major version.
 
-        Will return None if the versions is not semver/buildver/calver/simplever.
+        Will return None if the versions is not semver/buildver/calver/simplever/pep440.
         """
         if self.strategy not in (
             AwesomeVersionStrategy.SEMVER,
             AwesomeVersionStrategy.BUILDVER,
             AwesomeVersionStrategy.CALVER,
             AwesomeVersionStrategy.SIMPLEVER,
+            AwesomeVersionStrategy.PEP440,
         ):
             return None
         return AwesomeVersion(self.section(0))
@@ -328,13 +326,18 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the minor version.
 
-        Will return None if the versions is not semver/simplever/calver
+        Will return None if the versions is not semver/simplever/calver/pep440
         Will return None if the version does not have at least 2 sections.
         """
-        if self.strategy not in (
-            AwesomeVersionStrategy.SEMVER,
-            AwesomeVersionStrategy.CALVER,
-            AwesomeVersionStrategy.SIMPLEVER,
+        if (
+            self.strategy
+            not in (
+                AwesomeVersionStrategy.SEMVER,
+                AwesomeVersionStrategy.CALVER,
+                AwesomeVersionStrategy.SIMPLEVER,
+                AwesomeVersionStrategy.PEP440,
+            )
+            or self.sections < 2
         ):
             return None
 
@@ -345,7 +348,7 @@ class AwesomeVersion(_AwesomeVersionBase):
         """
         Return a AwesomeVersion representation of the patch version.
 
-        Will return None if the versions is not semver/simplever/calver
+        Will return None if the versions is not semver/simplever/calver/pep440
         Will return None if the version does not have at least 3 sections.
         """
         if (
@@ -354,6 +357,7 @@ class AwesomeVersion(_AwesomeVersionBase):
                 AwesomeVersionStrategy.SEMVER,
                 AwesomeVersionStrategy.CALVER,
                 AwesomeVersionStrategy.SIMPLEVER,
+                AwesomeVersionStrategy.PEP440,
             )
             or self.sections < 3
         ):
@@ -381,7 +385,10 @@ class AwesomeVersion(_AwesomeVersionBase):
         if self._modifier is not None:
             return self._modifier
 
-        if self.strategy == AwesomeVersionStrategy.SPECIALCONTAINER:
+        if self.strategy in (
+            AwesomeVersionStrategy.SPECIALCONTAINER,
+            AwesomeVersionStrategy.HEXVER,
+        ):
             return None
 
         modifier_string = None
@@ -410,6 +417,8 @@ class AwesomeVersion(_AwesomeVersionBase):
         """Return the modifier type of the version if any."""
         if self._modifier_type is not None:
             return self._modifier_type
+        if self.strategy == AwesomeVersionStrategy.HEXVER:
+            return None
         match = RE_MODIFIER.match(self.modifier or "")
         if match and len(match.groups()) >= 3:
             self._modifier_type = match.group(3)
@@ -438,9 +447,10 @@ class AwesomeVersion(_AwesomeVersionBase):
                 version_strategies[description.strategy] = description
 
         for description in version_strategies.values():
-            if description.pattern.match(self.string) is not None:
+            if description.pattern.match(self.string) is not None and (
+                description.validate is None or description.validate(self.string)
+            ):
                 return description.strategy
-
         return AwesomeVersionStrategy.UNKNOWN
 
     @property
